@@ -20,11 +20,10 @@ package plenigo::CheckoutHelper;
 
 use Moo;
 use Carp qw(confess);
-use Carp::Always;
 use Crypt::JWT qw(encode_jwt);
 use Data::UUID;
 
-our $VERSION = '2.0003';
+our $VERSION = '2.0004';
 
 has configuration => (
     is       => 'ro',
@@ -35,7 +34,7 @@ has configuration => (
 
 =cut
 
-=head2 hasAccess($customer_id, @product_ids)
+=head2 createCheckoutCode($product)
 
  Create checkout code necessary for plenigo checkout.
 
